# Sites

Below are two lists: Sites that are supported by rsstube, and sites that are explicitly not supported (because they do not seem to natively support RSS). If any of the unsupported sites actually do support RSS natively, or if you want me to add/look into a site that's not on either list, please let me know.

I tried to give sample URLs for each site or software. These are just examples and should not be taken as endorsements. I like some of them, but for some of them, I just needed examples.

- [Supported Sites](#supported-sites)
- [Unsupported Sites](#unsupported-sites)

## Supported Sites

These sites support RSS natively, and rsstube can get a feed for them.

- [Chirbit](#chirbit)
- [DeviantArt](#deviantart)
- [Hugo](#hugo)
- [Invidious](#invidious)
- [Mastodon](#mastodon)
- [Nitter](#nitter)
- [Pleroma](#pleroma)
- [Plume](#plume)
- [Podcasts](#podcasts)
- [Reddit](#reddit)
- [Soundcloud](#soundcloud)
- [Tumblr](#tumblr)
- [Vimeo](#vimeo)
- [WriteFreely](#writefreely)
- [YouTube](#youtube)

### Chirbit
Chirbit users have a built-in RSS feed at `https://www.chirbit.com/[username]/rss`. If a user's page URL is passed in, `rsstube` just appends `/rss` after the username. If a track URL (at `chirb.it`) is passed in, the page is downloaded, and the username is grabbed from the page.

Sample URLs:

- https://www.chirbit.com/Giannaa -> https://www.chirbit.com/Giannaa/rss
- https://chirb.it/9qxaAG -> https://www.chirbit.com/Giannaa/rss

### DeviantArt
DeviantArt RSS URLs are complicated, but the basic idea is `https://backend.deviantart.com/rss.xml` followed by arguments. A feed for a given user's deviations can be found at:
`https://backend.deviantart.com/rss.xml?type=deviation&q=by%3A[username]+sort%3Atime+meta%3Aall`. See [the DeviantArt page on RSS feeds](https://www.deviantart.com/developers/rss) for more information.

`rsstube` doesn't do anything fancy here; it just generates the above URL for the given user.

Sample URLs:

- https://www.deviantart.com/sashakhmel -> https://backend.deviantart.com/rss.xml?type=deviation&q=by%3Asashakhmel+sort%3Atime+meta%3Aall
- https://www.deviantart.com/sashakhmel/art/lady-in-armor-825805802 -> https://backend.deviantart.com/rss.xml?type=deviation&q=by%3Asashakhmel+sort%3Atime+meta%3Aall

### Hugo
Sites generated with [Hugo](https://gohugo.io/) have a feed at `/index.xml`. I don't know if this is true of all Hugo sites, but it at least sometimes works.

Sample URLs:

- https://gohugo.io/ -> https://gohugo.io/index.xml
- https://lesbianhacker.neocities.org/ -> https://lesbianhacker.neocities.org/index.xml

### Invidious
Invidious is basically a free software proxy to YouTube with [several public instances](https://github.com/omarroth/invidious/wiki/Invidious-Instances), and it supports URL schemes in the same way [YouTube](#youtube) does. It also supports other things, for instance, URLs in the form `https://www.youtube.com/user/[username]` have an Invidious RSS feed at `[invidious domain]/feed/channel/[username]`. Playlist feeds can be found at `[invidious domain]/feed/playlist/[playlist_id]`.

If the page must be downloaded to find additional information, `rsstube` looks for `<div class="h-box"> <a href="/channel/[channel_id]" style="display:block;width:fit-content;width:-moz-fit-content"> <div class="channel-profile">`, and uses that to form `[domain]/feed/channel/[channel_id]`.

Sample URLs:

- https://invidio.us/watch?v=UEQfaTntFNw -> https://invidio.us/feeds/videos.xml?channel_id=UCo3AxjxePfj6DHn03aiIhww
- http://axqzx4s6s54s32yentfqojs3x5i7faxza6xo3ehd4bzzsg2ii4fv2iid.onion/watch?v=4jYsu5-TJQ8 -> http://axqzx4s6s54s32yentfqojs3x5i7faxza6xo3ehd4bzzsg2ii4fv2iid.onion/feeds/videos.xml?channel_id=UCFn5CIjfAj-KZgJtsXw349g
- https://invidio.us/channel/UCqC_GY2ZiENFz2pwL0cSfAw -> https://invidio.us/feed/channel/UCqC_GY2ZiENFz2pwL0cSfAw

### Mastodon
Mastodon user pages are at `[domain]/@[username]`, and posts are at `[domain]/@[username]/[postID]`. Mastodon user pages can also be found at `[domain]/users/[username]` (I think for compatability with Pleroma). The RSS feed for a given user is at `[domain]/@[username].rss`.

Sample URLs:

- https://mastodon.social/@gargron -> https://mastodon.social/@gargron.rss

### Nitter
Nitter is like Invidious, but for Twitter. It has [several public instances](https://github.com/zedeus/nitter/wiki/Instances). Nitter feeds have URLs at `[nitter domain]/[username]/rss`.

Note, Twitter is not supported.

Sample URLs:

- https://nitter.net/doctorow -> https://nitter.net/doctorow/rss
- http://3nzoldnxplag42gqjs23xvghtzf6t6yzssrtytnntc6ppc7xxuoneoad.onion/doctorow/status/1214288190317592576#m -> http://3nzoldnxplag42gqjs23xvghtzf6t6yzssrtytnntc6ppc7xxuoneoad.onion/doctorow/rss

### Pleroma
Pleroma user URLs are at `[domain]/users/[username]`. The Atom feed for a given user is at `[domain]/users/[username]/feed.atom`. This may not work for all instances.

Sample URLs:

- https://kawen.space/users/314 -> https://kawen.space/users/314/feed.atom

### Plume
Some Plume pages directly link to the Atom feed in an alternate link. `rsstube` first looks for this link: `<link href='[domain]/@/[username]/atom.xml' rel='alternate' type='application/atom+xml'>`. If it doesn't find the link, it tries to create it. The feed for a given user is at `[domain]/@/[username]/atom.xml`. If the provided URL is a user's page (`[domain]/@/[username]`), it just puts the `atom.xml` on the end. If it's a blog post (`[domain]/~/[username]/[post-title]/`), it looks for a link to the user page: `<a rel="author" class="u-url" href="[domain]/@/[username]/"></a>` and appends the `atom.xml` to that.

Sample URLs:

- https://blog.funkwhale.audio/@/funkwhale -> https://blog.funkwhale.audio/@/funkwhale/atom.xml
- https://fediverse.blog/~/MusingsByRg/firefox-add-ons-for-the-active-user -> https://fediverse.blog/@/rgx/atom.xml

### Podcasts
A podcast is just an RSS feed, but a lot of people post links to specific services like Apple Podcasts, instead of just posting the feed link. `rsstube` supports the following podcast sites, so you should be able to put in the URL for a podcast, and it will return the RSS feed URL.

Basically, `rsstube` just looks on the page for a link to the actual RSS file.

Sites with sample URLs:

- Apple Podcasts (https://podcasts.apple.com/us/podcast/irl-online-life-is-real-life/id1247652431 -> https://feeds.mozilla-podcasts.org/irl)
- Castro.fm (https://castro.fm/podcast/b3891201-4d76-4152-adeb-ae3e13d17f29 -> https://www.smashingsecurity.com/rss)
- fyyd (https://fyyd.de/podcast/shades-of-brown/0 -> https://twoshadesofbrown.com/feed/podcast/)
- Google Podcasts (https://podcasts.google.com/?feed=aHR0cHM6Ly9wb2RjYXN0Lm5lYXJseW9ucmVkLmNvbS9mZWVkLnhtbA -> https://podcast.nearlyonred.com/feed.xml)
- Player.fm (https://player.fm/series/tea-with-queen-and-j -> http://feeds.soundcloud.com/users/soundcloud:users:83464467/sounds.rss)
- Pocket Casts (https://pca.st/iHi8 -> https://feeds.simplecast.com/ZL7iUDiH)

### Reddit
Reddit URLs are extremely hackable, so `rsstube` assumes the user wants a feed for the actual URL provided, not specifically a user or a subreddit. To get an RSS feed for a Reddit page, just add `/.rss` to the end of the URL.

Sample URLs:

- https://old.reddit.com/r/privacy/ -> https://old.reddit.com/r/privacy/.rss
- https://www.reddit.com/r/onions+tor+onionlovers/ -> https://www.reddit.com/r/onions+tor+onionlovers/.rss

### Soundcloud
Soundcloud users have built-in RSS feeds, which `rsstube` returns; **however, by default tracks are not added to them.** The feed comes in the form: `https://feeds.soundcloud.com/users/soundcloud:users:[user_id]/sounds.rss`

To get the user ID, we download the page and search for the string `soundcloud:users:[user_id]"`

Unfortunately, most Soundcloud RSS feeds will be empty, unless they are for a serialized podcast or something like that.

Sample URLs:

- https://soundcloud.com/greatnessgd -> https://feeds.soundcloud.com/users/soundcloud:users:2097827/sounds.rss
- https://soundcloud.com/user-98066669 -> https://feeds.soundcloud.com/users/soundcloud:users:261098918/sounds.rss

### Tumblr
Tumblr provides an RSS feed for a given page at `[page URL]/rss`. For example, the feed for `username`'s posts will be: `https://username.tumblr.com/rss`. If you wanted all of `username`'s posts that were tagged `funny`, you could use `https://username.tumblr.com/tagged/funny/rss`

(Note: Tumblr does not support HTTPS on all pages, so the URL may actually start with `http://` )

Sample URLs:

- https://william-snekspeare.tumblr.com/ -> https://william-snekspeare.tumblr.com/rss
- https://william-snekspeare.tumblr.com/tagged/comic -> https://william-snekspeare.tumblr.com/tagged/comic/rss

### Vimeo
The Vimeo RSS feed for a user comes in the form: `https://vimeo.com/user[user_id]/videos/rss`

If `rsstube` receives a URL in the form `https://vimeo.com/user[user_id]/` it can just append `videos/rss` to the end. If it receives a video URL, it will need to download the video page and find the user ID. It can be found in various parts of the page, including by searching for `creator_id`

Sample URLs:

- https://vimeo.com/user51602410 -> https://vimeo.com/user51602410/videos/rss
- https://vimeo.com/63502573 -> https://vimeo.com/user2617788/videos/rss

### Write.as
See [WriteFreely](#writefreely).

### WriteFreely
WriteFreely(/Write.as) puts an RSS feed at `[user page]/feed/`. For single-user instances, this means `[domain]/feed/`, and for multi-user instances, this means `[domain]/[username]/feed/`.

The user's page also lists the feed directly in a link element: `<link rel="alternate" type="application/rss+xml" title="[username] &raquo; Feed" href="[RSS link]" />`

Sample URLs:

- https://tomskee.dev/ -> https://tomskee.dev/feed/
- https://tomskee.dev/claiming-2020-for-myself -> https://tomskee.dev/feed/
- https://wordsmith.social/rgx/ -> https://wordsmith.social/rgx/feed/
- https://wordsmith.social/rgx/is-it-important-which-instance-you-are-in -> https://wordsmith.social/rgx/feed/

### YouTube
The YouTube RSS feed comes in the form: `https://www.youtube.com/feeds/videos.xml?channel_id=[channel_id]`

Some YouTube channels have a URL in the form: `https://www.youtube.com/channel/[channel_id]`. In this case, we just take the channel ID from the end of the URL. In the case of `https://www.youtube.com/user/[username]` we can instead use `https://www.youtube.com/feeds/videos.xml?user=[username]`. For a playlist (`https://www.youtube.com/playlist?list=[playlist_id]`) we can use `https://www.youtube.com/feeds/videos.xml?playlist_id=[playlist_id]`.

If the channel's URL is not in this form (e.g., if the user passes in a video URL), we download the page and try to get the channel ID from the metadata. YouTube seems to have moved this metadata info to JSON that's parsed by the JavaScript. `rsstube` now looks for the string: (`"channelId":"[channel_id]"`). If it's a user/channel page that for some reason wasn't already covered, we can also just use the canonical link to the /channel/ page (`<link rel="canonical" href="https://www.youtube.com/channel/[channel_id]">`).

Sample URLs:

- https://www.youtube.com/channel/UCqC_GY2ZiENFz2pwL0cSfAw -> https://www.youtube.com/feeds/videos.xml?channel_id=UCqC_GY2ZiENFz2pwL0cSfAw
- https://www.youtube.com/watch?v=XzIXc5CTC2M -> https://www.youtube.com/feeds/videos.xml?channel_id=UCexJsljKV3x4x8p0eyTrjVg
- https://www.youtube.com/watch?v=fFlfxwZDFzY&list=PL8D8D4240EC972114 (playlist - put this in quotes) -> https://www.youtube.com/feeds/videos.xml?playlist_id=PL8D8D4240EC972114

## Unsupported Sites

These sites are explicitly unsupported because they do not seem to support RSS natively. For these sites, you might have better luck with a tool like [RSS Box](https://github.com/stefansundin/rssbox) that can be run from your own server (or may have public instances) to create the RSS feed.

Links here are not guaranteed to be accurate but are included for some reference of why I believe the given site does not support RSS natively.

- Bandcamp [x](https://old.reddit.com/r/BandCamp/comments/6c47bh/question_no_more_rss_feeds/) [x](https://old.reddit.com/r/BandCamp/comments/9h2kcu/rss_reader_for_bandcamp_feed/)
- Meetup [requires API requests to be authenticated](https://www.meetup.com/meetup_api/auth/).
- Instagram [x](https://stackoverflow.com/questions/14747870/instagram-public-rss-feed)
- TikTok
- Twitch [x](https://discuss.dev.twitch.tv/t/twitch-rss-feed-link/1105)
- Twitter [x](https://twittercommunity.com/t/does-api-1-1-no-longer-support-rss-feeds/11257)
